{% load common_tags %}

{% comment %}
<!--
  Copyright (C) 2011 University of Dundee & Open Microscopy Environment.
  All rights reserved.

  This program is free software: you can redistribute it and/or modify
  it under the terms of the GNU Affero General Public License as
  published by the Free Software Foundation, either version 3 of the
  License, or (at your option) any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU Affero General Public License for more details.

  You should have received a copy of the GNU Affero General Public License
  along with this program.  If not, see <http://www.gnu.org/licenses/>.
-->


      <!-- This is a placeholder since we moved the group_user_dropdown out
      of the left_panel and up into the template above.
      However, because 3rd-party apps have extended page templates E.g. webtagging_search
      and omero.seracher have extended search.html, which still include
      this group_user_dropdown.html.
      So, we've removed the menu from here, so search.html simply includes
      this blank placeholder and the real menu is now in
      group_user_dropdown2.html
      -->

{% endcomment %}
